'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = visitor;
var arrowRegex = /^\s?(=>|→|throws)/;

function visitor(_ref) {
  var t = _ref.types,
      template = _ref.template,
      transform = _ref.transform;

  var assertTemplate = template('\n      assert.deepEqual($0, $1)\n  ');

  var throwsTemplate = template('\n      assert.throws(() => { $0 } , $1);\n  ');

  return {
    visitor: {
      ExpressionStatement: function ExpressionStatement(path) {
        var comments = path.node.trailingComments;
        if (comments && comments.length > 0 && comments[0].value.match(arrowRegex)) {
          var matches = comments[0].value.match(arrowRegex);
          var throws = matches[1] === 'throws';

          var child = path.node.expression;

          var rawComment = comments[0].value.replace(arrowRegex, '').trim();
          var comment = transform('() => (' + rawComment + ')').ast.program.body[0].expression.body;

          if (t.isCallExpression(child) && child.callee && child.callee.object && child.callee.object.name === 'console') {
            path.node.trailingComments = comments.splice(1); // eslint-disable-line
            var code = child.arguments[0];
            if (throws) {
              path.insertAfter(throwsTemplate(code, comment));
            } else {
              path.insertAfter(assertTemplate(code, comment));
            }
          } else {
            path.node.trailingComments = comments.splice(1); // eslint-disable-line
            if (throws) {
              path.replaceWith(throwsTemplate(child, comment));
            } else {
              path.replaceWith(assertTemplate(child, comment));
            }
          }
        }
      }
    }
  };
}